@@ -32,12 +32,11 @@
 
 from gettext import gettext as _
 
-import gi
-gi.require_version('Notify', '0.7')
-from gi.repository import Gtk, Gio, GLib, Gdk, Notify
+from gi.repository import Gtk, Gio, GLib, Gdk
 
 from gnomemusic import log
 from gnomemusic.mpris import MediaPlayer2Service
+from gnomemusic.widgets.aboutdialog import AboutDialog
 from gnomemusic.window import Window
 
 
@@ -89,20 +88,13 @@ class Application(Gtk.Application):
 
     @log
     def _about(self, action, param):
-        def about_response(dialog, response):
-            dialog.destroy()
-
-        builder = Gtk.Builder()
-        builder.add_from_resource('/org/gnome/Music/AboutDialog.ui')
-        about = builder.get_object('about_dialog')
-        about.set_transient_for(self._window)
-        about.connect("response", about_response)
-        about.show()
+        about = AboutDialog()
+        about.props.transient_for = self._window
 
     @log
     def do_startup(self):
         Gtk.Application.do_startup(self)
-        Notify.init(_("Music"))
+
         self._build_app_menu()
 
     @log
