@@ -183,18 +183,6 @@ class Window(Gtk.ApplicationWindow):
         self._box.pack_start(self.selection_toolbar, False, False, 0)
         self.add(self._box)
 
-        def songs_available_cb(available):
-            if available:
-                self._switch_to_player_view()
-            else:
-                self._switch_to_empty_view()
-
-        Query()
-        if Query.music_folder:
-            grilo.songs_available(songs_available_cb)
-        else:
-            self._switch_to_empty_view()
-
         self.headerbar._search_button.connect(
             'toggled', self._on_search_toggled)
         self.headerbar.connect(
@@ -209,6 +197,18 @@ class Window(Gtk.ApplicationWindow):
         self._box.show()
         self.show()
 
+        def songs_available_cb(available):
+            if available:
+                self._switch_to_player_view()
+            else:
+                self._switch_to_empty_view()
+
+        Query()
+        if Query.music_folder:
+            grilo.songs_available(songs_available_cb)
+        else:
+            self._switch_to_empty_view()
+
     @log
     def _switch_to_empty_view(self):
         did_initial_state = self.settings.get_boolean('did-initial-state')
@@ -229,6 +229,26 @@ class Window(Gtk.ApplicationWindow):
         self._key_press_event_id = self.connect(
             'key_press_event', self._on_key_press)
 
+        # FIXME: In case Grilo is already initialized before the views
+        # get created, they never receive a 'ready' signal to trigger
+        # population. To fix this another check was added to baseview
+        # to populate if grilo is ready at the end of init. For this to
+        # work however, the headerbar stack needs to be created and
+        # populated. This is done below, by binding headerbar.stack to
+        # to window._stack. For this to succeed, the stack needs to be
+        # filled with something: Gtk.Box.
+        # This is a bit of circular logic that needs to be fixed.
+        self.views[View.ALBUM] = Gtk.Box()
+        self.views[View.ARTIST] = Gtk.Box()
+        self.views[View.SONG] = Gtk.Box()
+        self.views[View.PLAYLIST] = Gtk.Box()
+        self.views[View.SEARCH] = Gtk.Box()
+
+        self.views[View.EMPTY].props.state = EmptyView.State.SEARCH
+        self.headerbar.props.state = HeaderBar.State.MAIN
+        self.headerbar.props.stack = self._stack
+        self.headerbar.searchbar.show()
+
         self.views[View.ALBUM] = AlbumsView(self, self.player)
         self.views[View.ARTIST] = ArtistsView(self, self.player)
         self.views[View.SONG] = SongsView(self, self.player)
@@ -244,13 +264,8 @@ class Window(Gtk.ApplicationWindow):
                 self._stack.add_titled(i, i.name, i.title)
             else:
                 self._stack.add_named(i, i.name)
-            GLib.idle_add(i.populate)
 
         self._stack.set_visible_child(self.views[View.ALBUM])
-        self.views[View.EMPTY].props.state = EmptyView.State.SEARCH
-        self.headerbar.props.state = HeaderBar.State.MAIN
-        self.headerbar.props.stack = self._stack
-        self.headerbar.searchbar.show()
 
     @log
     def _select_all(self, action=None, param=None):
@@ -304,25 +319,16 @@ class Window(Gtk.ApplicationWindow):
                 self.player.next()
             # Toggle repeat on Ctrl + R
             if keyval == Gdk.KEY_r:
-                if self.player.get_repeat_mode() == RepeatMode.SONG:
-                    self.player.set_repeat_mode(RepeatMode.NONE)
+                if self.player.props.repeat_mode == RepeatMode.SONG:
+                    self.player.props.repeat_mode = RepeatMode.NONE
                 else:
-                    self.player.set_repeat_mode(RepeatMode.SONG)
+                    self.player.props.repeat_mode = RepeatMode.SONG
             # Toggle shuffle on Ctrl + S
             if keyval == Gdk.KEY_s:
-                if self.player.get_repeat_mode() == RepeatMode.SHUFFLE:
-                    self.player.set_repeat_mode(RepeatMode.NONE)
+                if self.player.props.repeat_mode == RepeatMode.SHUFFLE:
+                    self.player.props.repeat_mode = RepeatMode.NONE
                 else:
-                    self.player.set_repeat_mode(RepeatMode.SHUFFLE)
-            # Headerbar switching
-            if keyval in [Gdk.KEY_1, Gdk.KEY_KP_1]:
-                self._toggle_view(View.ALBUM)
-            if keyval in [Gdk.KEY_2, Gdk.KEY_KP_2]:
-                self._toggle_view(View.ARTIST)
-            if keyval in [Gdk.KEY_3, Gdk.KEY_KP_3]:
-                self._toggle_view(View.SONG)
-            if keyval in [Gdk.KEY_4, Gdk.KEY_KP_4]:
-                self._toggle_view(View.PLAYLIST)
+                    self.player.props.repeat_mode = RepeatMode.SHUFFLE
         # Ctrl+Shift+<KEY>
         elif modifiers == shift_ctrl_mask:
             if keyval == Gdk.KEY_A:
@@ -332,6 +338,15 @@ class Window(Gtk.ApplicationWindow):
             # Go back from Album view on Alt + Left
             if keyval == Gdk.KEY_Left:
                 self.headerbar._on_back_button_clicked()
+            # Headerbar switching
+            if keyval in [Gdk.KEY_1, Gdk.KEY_KP_1]:
+                self._toggle_view(View.ALBUM)
+            if keyval in [Gdk.KEY_2, Gdk.KEY_KP_2]:
+                self._toggle_view(View.ARTIST)
+            if keyval in [Gdk.KEY_3, Gdk.KEY_KP_3]:
+                self._toggle_view(View.SONG)
+            if keyval in [Gdk.KEY_4, Gdk.KEY_KP_4]:
+                self._toggle_view(View.PLAYLIST)
         # No modifier
         else:
             if (keyval == Gdk.KEY_AudioPlay
@@ -423,7 +438,14 @@ class Window(Gtk.ApplicationWindow):
 
     @log
     def _toggle_view(self, view_enum):
-        self._stack.set_visible_child(self.views[view_enum])
+        # TODO: The SEARCH state actually refers to the child state of
+        # the search mode. This fixes the behaviour as needed, but is
+        # incorrect: searchview currently does not switch states
+        # correctly.
+        if (not self.headerbar.props.selection_mode
+                and not self.headerbar.props.state == HeaderBar.State.CHILD
+                and not self.headerbar.props.state == HeaderBar.State.SEARCH):
+            self._stack.set_visible_child(self.views[view_enum])
 
     @log
     def _on_search_toggled(self, button, data=None):
